Archiver class

Constructors

Archiver({required dynamic inputPath, required String outputFilePath, required String format})

Properties

format String
final
hashCode int
The hash code for this object.
no setterinherited
inputFileStream ↔ InputFileStream
latefinal
inputPath → dynamic
final
outputFilePath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spinner ↔ Spinner
latefinal

Methods

compress() → void
decompress() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited